@@ -32,8 +32,8 @@
 #define TDFX_NAME "TDFX"
 #define TDFX_DRIVER_NAME "tdfx"
 #define TDFX_MAJOR_VERSION 1
-#define TDFX_MINOR_VERSION 2
-#define TDFX_PATCHLEVEL 1
+#define TDFX_MINOR_VERSION 3
+#define TDFX_PATCHLEVEL 0
 
 struct _TDFXRec;
 typedef struct _TDFXRec *TDFXPtr;
@@ -229,6 +229,10 @@ typedef struct _TDFXRec {
   XF86VideoAdaptorPtr textureAdaptor;
   ScreenBlockHandlerProcPtr BlockHandler;
   OptionInfoPtr Options;
+
+  ScreenWakeupHandlerProcPtr coreWakeupHandler;
+  ScreenBlockHandlerProcPtr coreBlockHandler;
+
 } TDFXRec;
 
 typedef struct {
